@@ -5,11 +5,11 @@ class Dimension:
     list_metrics = []
     list_results = []
 
-    def __init__(self, nom, list_metrics) :
+    def __init__(self, nom, list_metrics):
         self.name = nom
         self.list_metrics = list_metrics
 
-    def dim_to_string(self) :
+    def dim_to_string(self):
         dico = {}
         dico["name"] = self.name
         dico["score"] = self.score
@@ -17,6 +17,8 @@ class Dimension:
         return dico
 
     def calc_score(self, g_onto, liste_map, g_map, raw_data, g_link):
+        self.list_results = []
+        self.score = 0
         for metric in self.list_metrics:
             result_metric = metric(g_onto, liste_map, g_map, raw_data, g_link)
             self.score += result_metric['score'] / len(self.list_metrics)
